Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(424)

Unified Diff: chrome/browser/sync/test/integration/preferences_helper.h

Issue 1545223002: Switch to standard integer types in chrome/browser/, part 4 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/preferences_helper.h
diff --git a/chrome/browser/sync/test/integration/preferences_helper.h b/chrome/browser/sync/test/integration/preferences_helper.h
index 2ce9a17d6fdaf32e8fe872b679de7bdd7b0131e6..aaa5ad882018a5188a6d25299de7c9be3f50f6f6 100644
--- a/chrome/browser/sync/test/integration/preferences_helper.h
+++ b/chrome/browser/sync/test/integration/preferences_helper.h
@@ -8,6 +8,8 @@
#include "base/files/file_path.h"
#include "base/values.h"
+#include <stdint.h>
+
#include <string>
class PrefService;
@@ -30,10 +32,10 @@ void ChangeBooleanPref(int index, const char* pref_name);
// |verifier| if DisableVerifier() hasn't been called.
void ChangeIntegerPref(int index, const char* pref_name, int new_value);
// Changes the value of the int64 preference with name |pref_name| in the
// profile with index |index| to |new_value|. Also changes its value in
// |verifier| if DisableVerifier() hasn't been called.
-void ChangeInt64Pref(int index, const char* pref_name, int64 new_value);
+void ChangeInt64Pref(int index, const char* pref_name, int64_t new_value);
// Changes the value of the double preference with name |pref_name| in the
// profile with index |index| to |new_value|. Also changes its value in
@@ -71,7 +73,7 @@ bool BooleanPrefMatches(const char* pref_name) WARN_UNUSED_RESULT;
// hasn't been called.
bool IntegerPrefMatches(const char* pref_name) WARN_UNUSED_RESULT;
// Used to verify that the int64 preference with name |pref_name| has the
// same value across all profiles. Also checks |verifier| if DisableVerifier()
// hasn't been called.
bool Int64PrefMatches(const char* pref_name) WARN_UNUSED_RESULT;
@@ -30,10 +32,10 @@ void ChangeBooleanPref(int index, const char* pref_name);
// |verifier| if DisableVerifier() hasn't been called.
void ChangeIntegerPref(int index, const char* pref_name, int new_value);
-// Changes the value of the int64 preference with name |pref_name| in the
+// Changes the value of the int64_t preference with name |pref_name| in the
// profile with index |index| to |new_value|. Also changes its value in
// |verifier| if DisableVerifier() hasn't been called.
@@ -71,7 +73,7 @@ bool BooleanPrefMatches(const char* pref_name) WARN_UNUSED_RESULT;
// hasn't been called.
bool IntegerPrefMatches(const char* pref_name) WARN_UNUSED_RESULT;
-// Used to verify that the int64 preference with name |pref_name| has the
+// Used to verify that the int64_t preference with name |pref_name| has the
// same value across all profiles. Also checks |verifier| if DisableVerifier()
// hasn't been called.

Powered by Google App Engine
This is Rietveld 408576698